@@ -266,7 +266,7 @@ def create_obj_from_arm_dod(proc, set_dims, version='', fill_value=-9999.,
 
     """
     # Set base url to get DOD information
-    base_url = 'https://pcm.arm.gov/pcmserver/dods/'
+    base_url = 'https://pcm.arm.gov/pcm/api/dods/'
 
     # Get data from DOD api
     with urllib.request.urlopen(base_url + proc) as url:
